# Changelog

## [1.2.1a1](https://github.com/OpenVoiceOS/ovos-core/tree/1.2.1a1) (2025-03-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.2.0a1...1.2.1a1)

**Merged pull requests:**

- fix:improve\_metrics\_reporting [\#664](https://github.com/OpenVoiceOS/ovos-core/pull/664) ([JarbasAl](https://github.com/JarbasAl))

## [1.2.0a1](https://github.com/OpenVoiceOS/ovos-core/tree/1.2.0a1) (2025-03-13)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.1.0...1.2.0a1)

**Merged pull requests:**

- feat:lang\_specific\_skills\_list [\#662](https://github.com/OpenVoiceOS/ovos-core/pull/662) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
